Tools for Organizing and Displaying Reports
===========================================

.. automodule:: nwbinspector
    :members:
    :no-undoc-members:
    :noindex:

.. toctree::
    :maxdepth: 4

.. automodule:: nwbinspector._organization
    :noindex:

.. automodule:: nwbinspector._formatting
    :noindex:
